@@ -9,7 +9,7 @@ use CLDR::Number::Data::Currency;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 with qw( CLDR::Number::Role::Format );
 
@@ -150,7 +150,7 @@ CLDR::Number::Format::Currency - Localized currency formatter using the Unicode
 
 =head1 VERSION
 
-This document describes CLDR::Number::Format::Currency v0.09, built with Unicode
+This document describes CLDR::Number::Format::Currency v0.10, built with Unicode
 CLDR v24.
 
 =head1 DEPRECATION
@@ -165,8 +165,8 @@ and to submit comments or concerns.
     # either
     use CLDR::Number::Format::Currency;
     $curf = CLDR::Number::Format::Currency->new(
-        locale   => 'en',
-        currency => 'USD',
+        locale        => 'en',
+        currency_code => 'USD',
     );
 
     # or
@@ -309,7 +309,7 @@ L<code.shutterstock.com|http://code.shutterstock.com/>.
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2013–2014 Shutterstock, Inc.
+© 2013–2015 Shutterstock, Inc.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
